aboutsummaryrefslogtreecommitdiff
path: root/webAO
diff options
context:
space:
mode:
authorstonedDiscord <Tukz@gmx.de>2022-07-16 14:00:35 +0200
committerstonedDiscord <Tukz@gmx.de>2022-07-16 14:00:35 +0200
commitf3359b60bde9014e3ee56daa3d4104d61d8ee149 (patch)
treed32c98b9f70a93cf7ac0d9c052e85e7a551f6c38 /webAO
parentf4c6e6b40d27536f1079a5ad7d9a267852daae3e (diff)
deskmod is actually a number
Diffstat (limited to 'webAO')
-rw-r--r--webAO/client.ts6
1 files changed, 3 insertions, 3 deletions
diff --git a/webAO/client.ts b/webAO/client.ts
index 3876011..6c56950 100644
--- a/webAO/client.ts
+++ b/webAO/client.ts
@@ -343,7 +343,7 @@ class Client extends EventEmitter {
/**
* Sends an in-character chat message.
* @param {string} deskmod controls the desk
* @param {string} speaking who is speaking
* @param {string} name the name of the current character
* @param {string} silent whether or not it's silent
@@ -363,7 +363,7 @@ class Client extends EventEmitter {
* @param {number} noninterrupting_preanim play the full preanim (optional)
*/
sendIC(
- deskmod: string,
+ deskmod: number,
preanim: string,
name: string,
emote: string,
@@ -412,7 +412,7 @@ class Client extends EventEmitter {
}
}
- const serverMessage = `MS#${escapeChat(deskmod)}#${escapeChat(preanim)}#${escapeChat(name)}#${escapeChat(emote)}`
+ const serverMessage = `MS#${deskmod}#${escapeChat(preanim)}#${escapeChat(name)}#${escapeChat(emote)}`
+ `#${escapeChat(message)}#${escapeChat(side)}#${escapeChat(sfx_name)}#${emote_modifier}`
+ `#${this.charID}#${sfx_delay}#${Number(objection_modifier)}#${Number(evidence)}#${Number(flip)}#${Number(realization)}#${text_color}#${extra_cccc}${extra_27}${extra_28}%`;
@@ -343,7 +343,7 @@ class Client extends EventEmitter {
/**
* Sends an in-character chat message.
- * @param {string} deskmod controls the desk
+ * @param {number} deskmod controls the desk
* @param {string} speaking who is speaking
* @param {string} name the name of the current character